
class BboxApiEndpoints():
    get_bbox_info               = ( 'get',  'v1/device' )
    set_display_luminosity      = ( 'put',  'v1/device/display' )
    reboot                      = ( 'post', 'v1/device/reboot' )
    get_token                   = ( 'get',  'v1/device/token' )
    get_all_connected_devices   = ( 'get',  'v1/hosts' )
    login                       = ( 'post', 'v1/login' )
    logout                      = ( 'post', 'v1/logout' )
    get_xdsl_info               = ( 'get',  'v1/wan/xdsl' )
    get_xdsl_stats              = ( 'get',  'v1/wan/xdsl/stats' )
    get_ip_stats                = ( 'get',  'v1/wan/ip/stats' )

'v1/airties'
'v1/alerts'
'v1/alerts/:id'
'v1/change-password'
'v1/configs'
'v1/configs/:id'
'v1/cpl'
'v1/device'
'v1/device/cpu'
'v1/device/display'
'v1/device/factory'
'v1/device/led'
'v1/device/log'
'v1/device/mem'
'v1/device/optimization'
'v1/device/printer'
'v1/device/reboot'
'v1/device/summary'
'v1/device/token'
'v1/device/usb'
'v1/device/usb/:id'
'v1/device/usb/dlna'
'v1/device/usb/printer'
'v1/device/usb/samba'
'v1/dhcp'
'v1/dhcp/clients'
'v1/dhcp/clients/:id'
'v1/dhcp/options'
'v1/dhcp/options/:id'
'v1/dhcp/stb/options'
'v1/dhcp6'
'v1/dhcp6/options'
'v1/dhcp6/options/:id'
'v1/dhcpv6/options'
'v1/dns/stats'
'v1/dyndns'
'v1/dyndns/:id'
'v1/firewall'
'v1/firewall/gamermode'
'v1/firewall/pingresponder'
'v1/firewall/rules'
'v1/firewall/rules/:id'
'v1/firewallv6'
'v1/firewallv6/rules/:id'
'v1/hosts'
'v1/hosts/:id'
'v1/hosts/me'
'v1/hosts/pauth'
'v1/iptv'
'v1/iptv/diags'
'v1/lan'
'v1/lan/ip'
'v1/lan/ip6'
'v1/lan/stats'
'v1/login with the correct password to get the BBOX_ID cookie. '
'v1/login'
'v1/logout'
'v1/map'
'v1/nat/dmz'
'v1/nat/rules'
'v1/nat/rules/:id'
'v1/notification'
'v1/notification/alert'
'v1/notification/alert/:id'
'v1/notification/contact'
'v1/notification/contact/:id'
'v1/notification/contacts'
'v1/notification/test'
'v1/oauth/authorize'
'v1/oauth/token'
'v1/parentalcontrol'
'v1/parentalcontrol/hosts'
'v1/parentalcontrol/scheduler'
'v1/parentalcontrol/unblock'
'v1/password-recovery'
'v1/password-recovery/verify'
'v1/pincode'
'v1/pincode/verify'
'v1/profile/account'
'v1/profile/calllog/:id'
'v1/profile/consumption'
'v1/remote/admin'
'v1/remote/proxywol'
'v1/reset-password'
'v1/services'
'v1/upnp/igd'
'v1/upnp/igd/rules'
'v1/usb/storage'
'v1/usersave'
'v1/voip/blockanon'
'v1/voip/callforward'
'v1/voip/calllog/:id'
'v1/voip/diag'
'v1/voip/dial'
'v1/voip/dial/:id'
'v1/voip/echotest'
'v1/voip/echotest/:id'
'v1/voip/features/acr/:id'
'v1/voip/fullcalllog/:id'
'v1/voip/phone/state'
'v1/voip/ringtest'
'v1/voip/ringtest/:id'
'v1/voip/scheduler'
'v1/voip/scheduler/number'
'v1/voip/scheduler/number/:id'
'v1/voip/voicemail'
'v1/wan/cable'
'v1/wan/diags'
'v1/wan/ftth/stats'
'v1/wan/ip'
'v1/wan/ip/stats'
'v1/wan/xdsl'
'v1/wan/xdsl/stats'
'v1/wireless'
'v1/wireless/:freqband/neighborhood'
'v1/wireless/:id'
'v1/wireless/24'
'v1/wireless/24/neighborhood'
'v1/wireless/24/stats'
'v1/wireless/5'
'v1/wireless/5/neighborhood'
'v1/wireless/5/stats'
'v1/wireless/acl'
'v1/wireless/acl/:id'
'v1/wireless/acl/rules'
'v1/wireless/acl/rules/:id'
'v1/wireless/repeater'
'v1/wireless/scheduler'
'v1/wireless/wps'
